import * as React from 'react';
import 'flatpickr/dist/themes/light.css';
import '@patternfly/patternfly/patternfly-date-picker.css';
import { DatePickerLocales } from './DatePickerUtils';
export interface DatePickerProps extends Omit<React.HTMLProps<HTMLInputElement>, 'onChange' | 'onFocus' | 'onBlur' | 'disabled' | 'ref'> {
    /** Additional classes added to the date time picker. */
    className?: string;
    /** Flag indicating whether the value of the date picker is invalid. */
    isInvalid?: boolean;
    /** Accessible label for the date picker */
    'aria-label'?: string;
    /** The minimum date that a user can start picking from. */
    minDate?: string;
    /** The maximum date that a user can pick to. */
    maxDate?: string;
    /** The case sensitive pattern of tokens representing desired readable format of the date. 'MM/DD/YYYY' by default. */
    dateFormat?: string;
    /** Flag indicating the date picker is disabled*/
    isDisabled?: boolean;
    /** Specify the locale of the date. */
    locale?: DatePickerLocales;
    /** String to display in the empty date picker field as a hint for the expected date format */
    placeholder?: string;
    /** A date string. The format could be the expected date format, or an ISO 8601 formatted date string */
    value?: string;
    /** Error message to display when the date is provided in an invalid format. */
    invalidFormatErrorMessage?: string;
    /** Error message to display when the date is provided in outside the valid date range. */
    dateOutOfRangeErrorMessage?: string;
    /** Error message to display when the date is provided before the provided minDate. */
    beforeMinDateErrorMessage?: string;
    /** Error message to display when the date is provided after the provided maxDate. */
    afterEndDateErrorMessage?: string;
}
interface DatePickerState {
    invalid: boolean;
    invalidText: string;
    flatpickrDateFormat: string;
}
export declare class DatePicker extends React.Component<DatePickerProps, DatePickerState> {
    static displayName: string;
    static defaultProps: {
        className: string;
        isInvalid: boolean;
        minDate: string;
        maxDate: string;
        dateFormat: string;
        isDisabled: boolean;
        locale: DatePickerLocales;
        placeholder: string;
        value: string;
        'aria-label': string;
    };
    constructor(props: DatePickerProps);
    private ref;
    private inputEl;
    private calendar;
    componentDidMount(): void;
    toggleCalendar: () => void;
    validateDate: (dateStr: string, event: React.KeyboardEvent | React.ChangeEvent) => void;
    onBlur: (event: React.ChangeEvent<HTMLInputElement>) => void;
    handleError: (errorMessage: string) => void;
    render(): JSX.Element;
}
export {};
//# sourceMappingURL=DatePicker.d.ts.map