"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DatePicker = void 0;
const tslib_1 = require("tslib");
const React = tslib_1.__importStar(require("react"));
const flatpickr_1 = tslib_1.__importDefault(require("flatpickr"));
const react_styles_1 = require("@patternfly/react-styles");
const l10n_1 = tslib_1.__importDefault(require("flatpickr/dist/l10n"));
require("flatpickr/dist/themes/light.css");
require("@patternfly/patternfly/patternfly-date-picker.css");
const date_picker_1 = tslib_1.__importDefault(require("@patternfly/react-styles/css/components/DatePicker/date-picker"));
const DatePickerUtils_1 = require("./DatePickerUtils");
const TextInput_1 = require("@patternfly/react-core/dist/js/components/TextInput/TextInput");
/**
 * @param format
 */
function mapToFlatpickrFormats(format) {
    let flatpickrFormat = '';
    for (const formatBlock of format.split(/(yyyy|mm|dd)/i)) {
        if (formatBlock.toLowerCase() === 'yyyy') {
            flatpickrFormat += 'Y';
        }
        else if (formatBlock.toLowerCase() === 'mm') {
            flatpickrFormat += 'm';
        }
        else if (formatBlock.toLowerCase() === 'dd') {
            flatpickrFormat += 'd';
        }
        else {
            flatpickrFormat += formatBlock;
        }
    }
    return flatpickrFormat;
}
/**
 * @param date
 */
function isValid(date) {
    return date && !isNaN(date.getDate());
}
class DatePicker extends React.Component {
    constructor(props) {
        super(props);
        this.ref = React.createRef();
        this.inputEl = React.createRef();
        this.calendar = null;
        this.toggleCalendar = () => {
            this.calendar && this.calendar.isOpen ? this.calendar.open() : this.calendar.close();
        };
        this.validateDate = (dateStr, event) => {
            const { dateFormat, minDate: minDateIn, maxDate: maxDateIn, invalidFormatErrorMessage, dateOutOfRangeErrorMessage, beforeMinDateErrorMessage, afterEndDateErrorMessage } = this.props;
            const { flatpickrDateFormat } = this.state;
            if (dateStr === '') {
                event.stopPropagation();
                return;
            }
            const date = this.calendar.parseDate(dateStr, flatpickrDateFormat);
            const minDate = this.calendar.parseDate(minDateIn, flatpickrDateFormat);
            const maxDate = this.calendar.parseDate(maxDateIn, flatpickrDateFormat);
            if (!isValid(date)) {
                this.handleError(invalidFormatErrorMessage || `Please use format: ${dateFormat}.`);
                event.stopPropagation();
            }
            else if (isValid(minDate) && isValid(maxDate)) {
                if (date < minDate || date > maxDate) {
                    this.handleError(dateOutOfRangeErrorMessage || `The date is outside the allowable range.`);
                    event.stopPropagation();
                }
                else {
                    this.setState({
                        invalid: false,
                        invalidText: ''
                    });
                }
            }
            else if (isValid(minDate) && date < minDate) {
                this.handleError(beforeMinDateErrorMessage || `Date is before the allowable range.`);
                event.stopPropagation();
            }
            else if (isValid(maxDate) && date > maxDate) {
                this.handleError(afterEndDateErrorMessage || `Date is after the allowable range.`);
                event.stopPropagation();
            }
            else {
                this.setState({
                    invalid: false,
                    invalidText: ''
                });
            }
        };
        this.onBlur = (event) => {
            this.validateDate(event.target.value, event);
        };
        this.handleError = (errorMessage) => {
            this.calendar.close();
            this.setState({
                invalid: true,
                invalidText: errorMessage
            });
        };
        this.state = {
            flatpickrDateFormat: mapToFlatpickrFormats(this.props.dateFormat),
            invalid: this.props.isInvalid,
            invalidText: ''
        };
    }
    componentDidMount() {
        const { dateFormat, minDate, maxDate, locale, value } = this.props;
        const { flatpickrDateFormat } = this.state;
        this.calendar = flatpickr_1.default(this.inputEl.current, {
            dateFormat: flatpickrDateFormat,
            locale: l10n_1.default[locale],
            minDate,
            maxDate,
            defaultDate: value,
            allowInput: true,
            static: true,
            allowInvalidPreload: true,
            errorHandler: () => {
                this.handleError(this.props.invalidFormatErrorMessage || `Please use format ${dateFormat}.`);
            },
            onReady: (date, format, fp) => {
                fp.calendarContainer.classList.add(date_picker_1.default.datePickerCalendar);
                fp.calendarContainer.parentElement.classList.remove('flatpickr-wrapper');
            },
            nextArrow: '<svg aria-hidden="true" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 512"><path fill="currentColor" d="M224.3 273l-136 136c-9.4 9.4-24.6 9.4-33.9 0l-22.6-22.6c-9.4-9.4-9.4-24.6 0-33.9l96.4-96.4-96.4-96.4c-9.4-9.4-9.4-24.6 0-33.9L54.3 103c9.4-9.4 24.6-9.4 33.9 0l136 136c9.5 9.4 9.5 24.6.1 34z" class=""></path></svg>',
            prevArrow: '<svg aria-hidden="true" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 512"><path fill="currentColor" d="M31.7 239l136-136c9.4-9.4 24.6-9.4 33.9 0l22.6 22.6c9.4 9.4 9.4 24.6 0 33.9L127.9 256l96.4 96.4c9.4 9.4 9.4 24.6 0 33.9L201.7 409c-9.4 9.4-24.6 9.4-33.9 0l-136-136c-9.5-9.4-9.5-24.6-.1-34z" class=""></path></svg>'
        });
        window.document.body.addEventListener('keydown', e => {
            if (e.code === 'Enter' && e.target === this.inputEl.current) {
                this.validateDate(e.target.value, e);
            }
            else if (e.code === 'Escape' && this.calendar.isOpen) {
                this.calendar.close();
            }
        }, true);
    }
    render() {
        const _a = this.props, { className, placeholder, isDisabled, 'aria-label': ariaLabel, 
        /* eslint-disable @typescript-eslint/no-unused-vars */
        isInvalid, pattern, value, dateFormat, minDate, maxDate, locale, invalidFormatErrorMessage, dateOutOfRangeErrorMessage, beforeMinDateErrorMessage, afterEndDateErrorMessage } = _a, 
        /* eslint-enable @typescript-eslint/no-unused-vars */
        props = tslib_1.__rest(_a, ["className", "placeholder", "isDisabled", 'aria-label', "isInvalid", "pattern", "value", "dateFormat", "minDate", "maxDate", "locale", "invalidFormatErrorMessage", "dateOutOfRangeErrorMessage", "beforeMinDateErrorMessage", "afterEndDateErrorMessage"]);
        return (React.createElement("div", Object.assign({ className: react_styles_1.css(date_picker_1.default.datePicker, className), ref: this.ref }, props),
            React.createElement(TextInput_1.TextInput, { isDisabled: isDisabled, iconVariant: "calendar", onClick: this.toggleCalendar, onBlur: this.onBlur, ref: this.inputEl, "aria-label": ariaLabel, placeholder: placeholder, validated: this.state.invalid ? 'error' : 'default' }),
            this.state.invalid && (React.createElement("div", { className: react_styles_1.css(date_picker_1.default.datePickerHelperText, date_picker_1.default.modifiers.error) }, this.state.invalidText))));
    }
}
exports.DatePicker = DatePicker;
DatePicker.displayName = 'DatePicker';
DatePicker.defaultProps = {
    className: '',
    isInvalid: false,
    minDate: '',
    maxDate: '',
    dateFormat: 'mm/dd/yyyy',
    isDisabled: false,
    locale: DatePickerUtils_1.DatePickerLocales.en,
    placeholder: 'mm/dd/yyyy',
    value: '',
    'aria-label': 'Date picker'
};
//# sourceMappingURL=DatePicker.js.map